@@ -1,4 +1,4 @@
-from .python_codon_tables import (available_codon_tables, 
+from .python_codon_tables import (available_codon_tables_names, 
                                   csv_string_to_codons_dict,
                                   get_codons_table,
                                   get_all_available_codons_tables,
